set terminal pdfcairo enhanced color size 4,4 fontscale 0.5\
    font 'Arial,14' linewidth 1 dl 5
    
set key font ',12'
set key bottom right

set output "predicted load curves eng stress.pdf"

set ylabel offset 1
set xlabel offset 0,0.5

set lmargin 9
set rmargin 9
set tmargin 3
set bmargin 6

a = 1

set style line 1 lw 2 ps 0.75 pt 2 lc rgb '#1B9E77' # dark teal
set style line 2 dashtype (2,2) lw 2 ps 0.75 pt 4 lc rgb '#D95F02' # dark orange
set style line 3 dashtype (4,2) lw 2 ps 0.75 pt 6 lc rgb '#7570B3' # dark lilac
set style line 4 dashtype (6,2) lw 2 ps 0.75 pt 8 lc rgb '#E7298A' # dark magenta
set style line 5 dashtype 5 lw 2 ps 0.75 pt 10 lc rgb '#66A61E' # dark lime green
set style line 6 dashtype 6 lw 2 ps 0.75 pt 2 lc rgb '#E6AB02' # dark banana
set style line 7 dashtype 7 lw 2 ps 0.75 pt 3 lc rgb '#A6761D' # dark tan
set style line 8 dashtype 8 lw 2 ps 0.75 pt 5 lc rgb '#666666' # dark gray
set style line 9 dashtype 9 lw 2 ps 0.75 pt 7 lc rgb "#cab2d6"
set style line 10 dashtype 10 lw 2 ps 0.75 pt 9 lc rgb "#6a3d9a"
set style line 11 dashtype 11 lw 2 ps 0.75 pt 11 lc rgb "#222222"
set style line 12 dashtype 12 lw 2 ps 0.75 pt 13 lc rgb "#b15928"
set style line 13 dashtype 1 lw 2 ps 0.75 pt 13 lc rgb "#ffffff"


#Director-Strain (MASTER CURVE)
theta(x,m,n) = m-n*x

#Stress-Strain (MASTER CURVE)
sigma(x,A,c,d) = A*log((1+c*x)/(1-d*x))

#Inverted Strain-director CONSTANT FOR INITIAL STRAIN ON MASTER CURVE
epsilonINITIAL(t0,m,n) = (m-t0)/n

#FINAL STRESS ON MASTER CURVE (x is the stress applied)
sigmaFINAL(x,t0,m,n,A,c,d) = sigma(epsilonINITIAL(t0,m,n),A,c,d) + x

#Inverted Strain-director CONSTANT FOR INITIAL STRAIN ON MASTER CURVE
epsilonFINAL(strain,t0,m,n) = strain + epsilonINITIAL(t0,m,n)

#Final Strain along x
FinalStrainX(STRESS,t0,m,n,A,c,d) = epsilonFINAL(STRESS,t0,m,n,A,c,d) - epsilonINITIAL(t0,m,n)

#INITIAL STRESS ON MASTER CURVE
sigmaINITIAL(x,t0,m,n,A,c,d) = sigma(epsilonINITIAL(t0,m,n),A,c,d)

#FINAL STRESS
stress(strain,t0,m,n,A,c,d) = sigma(epsilonFINAL(strain,t0,m,n),A,c,d)-sigma(epsilonINITIAL(t0,m,n),A,c,d)

set yrange [-1:7]
set ylabel "Engineering stress [MPa]"
set xlabel "Strain {/Symbol e}_x"
set xrange [0:1.2]

m = 68.5
n = 27.6
A = 4.39
c = 0.4257
d = 0.4441

# m = 68.5
# n = 27.6
# A = 1
# c = 1
# d = 1


off70 = 39542.3600
off54 = 32237.0300
off39 = 32761.4900
off28 = 53418.8200
off19 = 56196.5500


plot stress(x,70.5,m,n,A,c,d)/(x+1) ls 2 dashtype 2 title "{/Symbol q}_0 = 70{\260}",\
    stress(x,54.16,m,n,A,c,d)/(x+1) ls 3 dashtype 2 title "54{\260}",\
    stress(x,38.8,m,n,A,c,d)/(x+1) ls 4 dashtype 2 title "39{\260}",\
    stress(x,27.8,m,n,A,c,d)/(x+1) ls 5 dashtype 2 title "28{\260}",\
    stress(x,19.0,m,n,A,c,d)/(x+1) ls 6 dashtype 2 title "19{\260}",\
    "70.txt" u 1:(($2-off70)/(($1+1)*1000000)) ls 2 notitle,\
    "54.txt" u 1:(($2-off54)/(($1+1)*1000000)) ls 3 notitle,\
    "39.txt" u 1:(($2-off39)/(($1+1)*1000000)) ls 4 notitle,\
    "28.txt" u 1:(($2-off28)/(($1+1)*1000000)) ls 5 notitle,\
    "19.txt" u 1:(($2-off19)/(($1+1)*1000000)) ls 6 notitle,\

# plot FinalStrainX(x,65.0,m,n,A,c,d) ls 1 title "{/Symbol q}_0 = 65{\260}",\
    # FinalStrainX(x,40.0,m,n,A,c,d) ls 2 title "40{\260}",\
    # FinalStrainX(x,30.0,m,n,A,c,d) ls 3 title "30{\260}",\
    # FinalStrainX(x,20.0,m,n,A,c,d) ls 4 title "20{\260}",\

#pause -1